Mailing List
------------
The Falcon community maintains a mailing list that you can use to share
your ideas and ask questions about the framework. We use the appropriately
minimalistic `Librelist <http://librelist.com/>`_ to host the discussions.

Subscribing is super easy and doesn't require any account setup. Simply
send an email to falcon@librelist.com and follow the instructions in the
reply. For more information about managing your subscription, check out
the `Librelist help page <http://librelist.com/help.html>`_.

While we don't have an official code of conduct, we do expect everyone
who participates on the mailing list to act professionally, and lead
by example in encouraging constructive discussions. Each individual in
the community is responsible for creating a positive, constructive, and
productive culture.

`Discussions are archived <http://librelist.com/browser/falcon>`_
for posterity.

Submit Issues
-------------
If you have an idea for a feature, run into something that is harder to
use than it should be, or find a bug, please let the crew know
in **#falconframework** and/or by
`submitting an issue <https://github.com/racker/falcon/issues>`_. We
need your help to make Falcon awesome!

Pay it Forward
--------------
We'd like to invite you to help other community members with their
questions in IRC, and to peer-review
`pull requests <https://github.com/racker/falcon/pulls>`_. If you use the
Chrome browser, we recommend installing the
`NotHub extension <http://nothub.org/>`_ to stay up to date with PRs.